@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2022 Leandro Nini
+ * Copyright 2011-2023 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -49,7 +49,7 @@
 
 #include "sidcxx11.h"
 
-inline void debug(const TCHAR *msg, const TCHAR *val)
+inline void debug(MAYBE_UNUSED const TCHAR *msg, MAYBE_UNUSED const TCHAR *val)
 {
 #ifndef NDEBUG
     SID_COUT << msg << val << std::endl;
@@ -91,6 +91,7 @@ void IniConfig::clear()
     sidplay2_s.kernalRom.clear();
     sidplay2_s.basicRom.clear();
     sidplay2_s.chargenRom.clear();
+    sidplay2_s.verboseLevel = 0;
 
     console_s.ansi          = false;
     console_s.topLeft       = '+';
@@ -119,6 +120,9 @@ void IniConfig::clear()
     emulation_s.bias            = 0.5;
     emulation_s.filterCurve6581 = 0.5;
     emulation_s.filterCurve8580 = 0.5;
+    emulation_s.powerOnDelay = -1;
+    emulation_s.samplingMethod = SidConfig::RESAMPLE_INTERPOLATE;
+    emulation_s.fastSampling = false;
 }
 
 
@@ -334,6 +338,8 @@ void IniConfig::readSidplay2(iniHandler &ini)
     sidplay2_s.kernalRom = readString(ini, TEXT("Kernal Rom"));
     sidplay2_s.basicRom = readString(ini, TEXT("Basic Rom"));
     sidplay2_s.chargenRom = readString(ini, TEXT("Chargen Rom"));
+
+    readInt(ini, TEXT("VerboseLevel"), sidplay2_s.verboseLevel);
 }
 
 
@@ -421,6 +427,21 @@ void IniConfig::readEmulation(iniHandler &ini)
     readDouble(ini, TEXT("FilterBias"), emulation_s.bias);
     readDouble(ini, TEXT("FilterCurve6581"), emulation_s.filterCurve6581);
     readDouble(ini, TEXT("FilterCurve8580"), emulation_s.filterCurve8580);
+
+    readInt(ini, TEXT("PowerOnDelay"), emulation_s.powerOnDelay);
+
+    {
+        SID_STRING str = readString(ini, TEXT("Sampling"));
+        if (!str.empty())
+        {
+            if (str.compare(TEXT("INTERPOLATE")) == 0)
+                emulation_s.samplingMethod = SidConfig::INTERPOLATE;
+            else if (str.compare(TEXT("RESAMPLE")) == 0)
+                emulation_s.samplingMethod = SidConfig::RESAMPLE_INTERPOLATE;
+        }
+    }
+
+    readBool(ini, TEXT("ResidFastSampling"), emulation_s.fastSampling);
 }
 
 class iniError
@@ -498,7 +519,7 @@ SID_STRING getConfigPath()
     return configPath;
 }
 
-bool tryOpen(iniHandler &ini)
+bool tryOpen(MAYBE_UNUSED iniHandler &ini)
 {
 #ifdef _WIN32
     {
@@ -540,5 +561,8 @@ void IniConfig::read()
     readConsole   (ini);
     readAudio     (ini);
     readEmulation (ini);
+
+    m_fileName = ini.getFilename();
+
     ini.close();
 }
