@@ -179,7 +179,6 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
     m_outfile(NULL),
     m_filename(""),
     m_quietLevel(0),
-    m_verboseLevel(0),
     m_cpudebug(false),
     newSonglengthDB(false)
 {
@@ -218,6 +217,8 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
         m_engCfg.ciaModel        = emulation.ciaModel;
 #endif
         m_engCfg.frequency    = audio.frequency;
+        m_engCfg.samplingMethod = emulation.samplingMethod;
+        m_engCfg.fastSampling = emulation.fastSampling;
         m_channels            = audio.channels;
         m_precision           = audio.precision;
         m_filter.enabled      = emulation.filter;
@@ -225,6 +226,9 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
         m_filter.filterCurve6581 = emulation.filterCurve6581;
         m_filter.filterCurve8580 = emulation.filterCurve8580;
 
+        if (emulation.powerOnDelay >= 0)
+            m_engCfg.powerOnDelay    = emulation.powerOnDelay;
+
         if (!emulation.engine.empty())
         {
             if (emulation.engine.compare(TEXT("RESIDFP")) == 0)
@@ -256,6 +260,8 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
         }
     }
 
+    m_verboseLevel = (m_iniCfg.sidplay2()).verboseLevel;
+
     createOutput (OUT_NULL, nullptr);
     createSidEmu (EMU_NONE);
 
@@ -680,19 +686,20 @@ void ConsolePlayer::emuflush ()
 
 
 // Out play loop to be externally called
-bool ConsolePlayer::play ()
+bool ConsolePlayer::play()
 {
+    uint_least32_t retSize = 0;
     if (m_state == playerRunning)
     {
         updateDisplay();
 
         // Fill buffer
-        short *buffer = m_driver.selected->buffer ();
-        const uint_least32_t length = m_driver.cfg.bufSize;
-        const uint_least32_t ret = m_engine.play (buffer, length);
-        if (ret < length)
+        short *buffer = m_driver.selected->buffer();
+        const uint_least32_t length = getBufSize();
+        retSize = m_engine.play(buffer, length);
+        if (retSize < length)
         {
-            if (m_engine.isPlaying ())
+            if (m_engine.isPlaying())
             {
                 m_state = playerError;
             }
@@ -703,7 +710,7 @@ bool ConsolePlayer::play ()
     switch (m_state)
     {
     case playerRunning:
-        m_driver.selected->write ();
+        m_driver.selected->write(retSize);
         // fall-through
     case playerPaused:
         // Check for a keypress (approx 250ms rate, but really depends
@@ -750,6 +757,49 @@ void ConsolePlayer::stop ()
 }
 
 
+uint_least32_t ConsolePlayer::getBufSize()
+{
+    if (m_timer.starting && (m_timer.current >= m_timer.start))
+    {   // Switch audio drivers.
+        m_timer.starting = false;
+        m_driver.selected = m_driver.device;
+        memset(m_driver.selected->buffer (), 0, m_driver.cfg.bufSize);
+        m_speed.current = 1;
+        m_engine.fastForward(100);
+        if (m_cpudebug)
+            m_engine.debug (true, nullptr);
+    }
+    else if ((m_timer.stop != 0) && (m_timer.current >= m_timer.stop))
+    {
+        m_state = playerExit;
+        for (;;)
+        {
+            if (m_track.single)
+                return 0;
+            // Move to next track
+            m_track.selected++;
+            if (m_track.selected > m_track.songs)
+                m_track.selected = 1;
+            if (m_track.selected == m_track.first)
+                return 0;
+            m_state = playerRestart;
+            break;
+        }
+        if (m_track.loop)
+            m_state = playerRestart;
+    }
+    else
+    {
+        uint_least32_t remaining = m_timer.stop - m_timer.current;
+        uint_least32_t bufSize = remaining * m_driver.cfg.bytesPerMillis();
+        if (bufSize < m_driver.cfg.bufSize)
+            return bufSize;
+    }
+
+    return m_driver.cfg.bufSize;
+}
+
+
 // External Timer Event
 void ConsolePlayer::updateDisplay()
 {
@@ -772,36 +822,6 @@ void ConsolePlayer::updateDisplay()
     }
 
     m_timer.current = milliseconds;
-
-    if (m_timer.starting && (milliseconds >= m_timer.start))
-    {   // Switch audio drivers.
-        m_timer.starting = false;
-        m_driver.selected = m_driver.device;
-        memset(m_driver.selected->buffer (), 0, m_driver.cfg.bufSize);
-        m_speed.current = 1;
-        m_engine.fastForward(100);
-        if (m_cpudebug)
-            m_engine.debug (true, nullptr);
-    }
-    else if ((m_timer.stop != 0) && (milliseconds >= m_timer.stop))
-    {
-        m_state = playerExit;
-        for (;;)
-        {
-            if (m_track.single)
-                return;
-            // Move to next track
-            m_track.selected++;
-            if (m_track.selected > m_track.songs)
-                m_track.selected = 1;
-            if (m_track.selected == m_track.first)
-                return;
-            m_state = playerRestart;
-            break;
-        }
-        if (m_track.loop)
-            m_state = playerRestart;
-    }
 }
 
 void ConsolePlayer::displayError (const char *error)
